@@ -62,7 +62,7 @@ is defined as :class:`NameSpaceDict`.
 
 The `--template` option
 
-This implementation is compatible with Python 2.5+ and Python 3.
+This implementation is compatible with Python 2.4+ and Python 3.
 
 Examples
 ========
@@ -76,7 +76,7 @@ Examples
 While a normal dict has special attributes
 
 >>> dict().__setattr__ #doctest: +ELLIPSIS
-<method-wrapper '__setattr__' of dict object ...>
+<method-wrapper ...>
 
 the namespace dict special attributes are hidden:
 
@@ -150,12 +150,14 @@ try:
 except AttributeError:
     try:
         import stringformat
-        def sformat (fmtspec, *args, **kwargs):
-            return stringformat.FormattableString(fmtspec).format(
-                *args, **kwargs)
     except ImportError:
-        printf('error: stringformat missing. Try `easy_install stringformat`.',
-               file=sys.stderr)
+        try:
+            import stringformat_local as stringformat
+        except ImportError:
+            printf('error: (nd) stringformat missing. Try `easy_install stringformat`.', file=sys.stderr)
+    def sformat (fmtspec, *args, **kwargs):
+        return stringformat.FormattableString(fmtspec).format(
+            *args, **kwargs)
 
 # (progn (forward-line 1) (snip-insert-mode "py.f.isstring" t) (insert "\n"))
 # hide from 2to3
@@ -194,9 +196,9 @@ __all__ = [
     'NameSpaceNS',
     ]
 
-dbg_comm = globals()['dbg_comm'] if 'dbg_comm' in globals() else '# '
-dbg_twid = globals()['dbg_twid'] if 'dbg_twid' in globals() else 9
-dbg_fwid = globals()['dbg_fwid'] if 'dbg_fwid' in globals() else 20
+dbg_comm = ((('dbg_comm' in globals()) and (globals()['dbg_comm'])) or ('# '))
+dbg_twid = ((('dbg_twid' in globals()) and (globals()['dbg_twid'])) or (9))
+dbg_fwid = ((('dbg_fwid' in globals()) and (globals()['dbg_fwid'])) or (20))
 
 # (progn (forward-line 1) (snip-insert-mode "py.b.dbg.setup" t) (insert "\n"))
 # (progn (forward-line 1) (snip-insert-mode "py.b.strings" t) (insert "\n"))
@@ -555,12 +557,12 @@ class NameSpaceDict(NameSpaceMeta(expose_dict=2)):
 # (progn (forward-line 1) (snip-insert-mode "py.f.hl" t) (insert "\n"))
 hlr = None
 def hlcr(title=None, tag='|||' ':CHP:|||', rule_width=50, **kwargs): # ||:fnc:||
-    comm = globals()['dbg_comm'] if 'dbg_comm' in globals() else '# '
+    comm = ((('dbg_comm' in globals()) and (globals()['dbg_comm'])) or ('# '))
     dstr = []
     dstr.append(''.join((comm, '-' * rule_width)))
     if title:
         dstr.append(sformat('{0}{2:^{1}} {3!s}',
-                comm, globals()['dbg_twid'] if 'dbg_twid' in globals() else 9,
+                comm, ((('dbg_twid' in globals()) and (globals()['dbg_twid'])) or (9)),
                 tag, title))
         dstr.append(''.join((comm, '-' * rule_width)))
     return '\n'.join(dstr)
@@ -1202,8 +1204,11 @@ def main(argv):                                            # ||:fnc:||
     try:
         import argparse
     except ImportError:
-        printe('error: argparse missing. Try `easy_install argparse`.')
-        sys.exit(1)
+        try:
+            import argparse_local as argparse
+        except ImportError:
+            printe('error: argparse missing. Try `easy_install argparse`.')
+            sys.exit(1)
 
     parser = argparse.ArgumentParser(add_help=False)
     # parser.add_argument('--sum', dest='accumulate', action='store_const',
@@ -1283,9 +1288,9 @@ def main(argv):                                            # ||:fnc:||
         cmd_line = argv
         sys.stderr.write(sformat(
                 "{0}{3:^{1}} {4:<{2}s}: ]{5!s}[\n",
-                globals()['dbg_comm'] if 'dbg_comm' in globals() else '# ',
-                globals()['dbg_twid'] if 'dbg_twid' in globals() else 9,
-                globals()['dbg_fwid'] if 'dbg_fwid' in globals() else 15,
+                ((('dbg_comm' in globals()) and (globals()['dbg_comm'])) or ('# ')),
+                ((('dbg_twid' in globals()) and (globals()['dbg_twid'])) or (9)),
+                ((('dbg_fwid' in globals()) and (globals()['dbg_fwid'])) or (15)),
                 ':DBG:', 'cmd_line', cmd_line))
 
     # at least use `quiet` to suppress the setdefaultencoding warning
