@@ -46,9 +46,9 @@ def printe(*args, **kwargs):
     sys.stderr.write(' '.join(args))
     sys.stderr.write('\n')
 
-dbg_comm = globals()['dbg_comm'] if 'dbg_comm' in globals() else '# '
-dbg_twid = globals()['dbg_twid'] if 'dbg_twid' in globals() else 9
-dbg_fwid = globals()['dbg_fwid'] if 'dbg_fwid' in globals() else 15
+dbg_comm = ((('dbg_comm' in globals()) and (globals()['dbg_comm'])) or ('# '))
+dbg_twid = ((('dbg_twid' in globals()) and (globals()['dbg_twid'])) or (9))
+dbg_fwid = ((('dbg_fwid' in globals()) and (globals()['dbg_fwid'])) or (15))
 
 # --------------------------------------------------
 # @|:uc_descr_beg:|>
